@@ -52,6 +52,29 @@ def femurOR(mkrs, s='R'):
 
 
 
+def patellaOR(mkrs, s='R'):
+
+    PPCR = mkrs['PPCR']
+    PDCR = mkrs['PDCR']
+    PMFLc = mkrs['PMFLc']
+    PLE = mkrs['PLE']
+
+    O = PDCR.copy()
+
+    K = getVersor(PPCR - PDCR)
+    if s == 'R':
+        J = getVersor(np.cross(K, PLE - PMFLc))
+    else:
+        J = -getVersor(np.cross(K, PLE - PMFLc))
+    I = getVersor(np.cross(J, K))
+
+    R = np.array((J.T, K.T, I.T))   # 3 x 3 x N
+    R = np.transpose(R, (2,1,0))  # N x 3 x 3
+
+    return R, O
+
+
+
 def tibiaORLW(mkrs, s='R'):
 
     TKC = mkrs['TKC']
@@ -249,3 +272,4 @@ def get3StrainGagesSensorModel():
 register = {}
 register['femurOR'] = femurOR
 register['tibiaOR'] = tibiaOR
+register['patellaOR'] = patellaOR
