@@ -43,9 +43,15 @@ def performAnalysis(
     mkrsLoc = {m: np.array(params['mkrsLoc'][m]['pos']) for m in params['mkrsLoc']}
     
     mkrsSegs = {}
+    segsMkrs = {}
     for m in params['mkrsLoc']:
         if 'fixedTo' in params['mkrsLoc'][m]:
-            mkrsSegs[m] = params['mkrsLoc'][m]['fixedTo']
+            fixedTo = params['mkrsLoc'][m]['fixedTo']
+            mkrsSegs[m] = fixedTo
+            if fixedTo not in segsMkrs:
+                segsMkrs[fixedTo] = []
+            segsMkrs[fixedTo].append(m)
+            
             
     ALs = {m: np.array(params['mkrsLoc'][m]['pos']) for m in params['mkrsLoc']}
 
@@ -102,6 +108,8 @@ def performAnalysis(
             R, T, info = kine.rigidBodySVDFun(mkrs, mkrList, args)
             RT = kine.composeRotoTranslMatrix(R, T)
             RTs[segName] = RT
+            usedALs = {m: ALs[m] for m in segsMkrs[segName]}
+            allALs.update(kine.changeMarkersReferenceFrame(usedALs, RT))
             pose = {}
             pose['matrix'] = RT
             pose['RMSE'] = info['RMSE']
