@@ -319,7 +319,7 @@ def performSpineAnalysis2(
     markersNew = {}
     markersNew['SACR'] = 0.5 * (markers['RPSI'] + markers['LPSI'])
     if 'L4' not in markers2:
-        markersNew['L4'] = 0.5 * (markers['RL4'] + markers['LL4'])
+        markersNew['L4'] = 0.5 * (markers['L4R'] + markers['L4L'])
     markers2.update(markersNew)
     
     # Express points in PELVIS anatomical reference frame
@@ -327,8 +327,8 @@ def performSpineAnalysis2(
         'C7',
         'T12',
         'L2',
-        'LL4',
-        'RL4',
+        'L4L',
+        'L4R',
         'L4',
         'LASI',
         'RASI',
