@@ -148,7 +148,7 @@ def duplicateMarkersFromRigidClusters(
 
 
 def updateParams(params):
-    lastVersion = 2
+    lastVersion = 4
     if 'version' not in params:
         if 'defSegPoses' not in params:
             ver = 0
@@ -206,5 +206,24 @@ def updateParams(params):
                 }
             ]
             
+        elif v == 3:
+            
+            params2['defScenes'] = [
+                {
+                     "name": "my_scene",
+                     "geomItems": "all_selected",
+                     "pointItems": "all_selected",
+                     "ref": "my_ref",
+                     "frames": "first_and_last",
+                     "exporter": "XML3Matic"
+                }
+            ]
+            params2['useScenes'] = {
+                "list": [
+                    "my_scene"
+                ],
+                "selected": []
+            }
+            
     params2['version'] = lastVersion
     return params2
